==> nextcloud-13.0.1.tgz: nextcloud/apps/twofactor_backupcodes/l10n/pl.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "Generate backup codes" : "Generowanie kodów zapasowych",
    "Backup codes have been generated. {{used}} of {{total}} codes have been used." : "Kody zapasowe zostały wygenerowane. {{used}} z {{total}} kodów zostało wykorzystanych.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "To są kody zapasowe. Proszę je zapisać i/lub wydrukować, ponieważ później nie będzie można ich ponownie odczytać",
    "Save backup codes" : "Zapisz kody zapasowe",
    "Print backup codes" : "Drukuj kody zapasowe",
    "Regenerate backup codes" : "Ponownie generuj kody zapasowe",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Jeśli generujesz kody zapasowe ponownie, automatycznie unieważniasz stare kody.",
    "An error occurred while generating your backup codes" : "Wystąpił błąd podczas generowania kodów zapasowych.",
    "Nextcloud backup codes" : "Kody zapasowe Nextcloud",
    "You created two-factor backup codes for your account" : "Stworzyłeś zapasowe kody uwierzytelnienia dwuetapowego swojego konta",
    "Backup code" : "Kod zapasowy",
    "Use backup code" : "Użyj kodu zapasowego",
    "Second-factor backup codes" : "Kody zapasowe uwierzytelnienia dwuskładnikowego"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> nextcloud-14.0.1.tgz: nextcloud/apps/twofactor_backupcodes/l10n/pl.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "Generate backup codes" : "Generowanie kodów zapasowych",
    "Backup codes have been generated. {{used}} of {{total}} codes have been used." : "Kody zapasowe zostały wygenerowane. {{used}} z {{total}} kodów zostało wykorzystanych.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "To są kody zapasowe. Proszę je zapisać i/lub wydrukować, ponieważ później nie będzie można ich ponownie odczytać",
    "Save backup codes" : "Zapisz kody zapasowe",
    "Print backup codes" : "Drukuj kody zapasowe",
    "Regenerate backup codes" : "Ponownie generuj kody zapasowe",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Jeśli generujesz kody zapasowe ponownie, automatycznie unieważniasz stare kody.",
    "An error occurred while generating your backup codes" : "Wystąpił błąd podczas generowania kodów zapasowych.",
    "Nextcloud backup codes" : "Kody zapasowe Nextcloud",
    "You created two-factor backup codes for your account" : "Stworzyłeś zapasowe kody uwierzytelnienia dwuetapowego swojego konta",
    "Backup code" : "Kod zapasowy",
    "Use backup code" : "Użyj kodu zapasowego",
    "Two factor backup codes" : "Kody zapasowe uwierzytelnienia dwuskładnikowego",
    "A two-factor auth backup codes provider" : "Dostawca dwuskładnikowych kodów zapasowych ",
    "Second-factor backup codes" : "Kody zapasowe uwierzytelnienia dwuskładnikowego"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
